import 'package:firebase_auth/firebase_auth.dart';

abstract class AuthService {

  static final FirebaseAuth _auth = FirebaseAuth.instance;
  
  static Future<String> uid() async {
    return (await _auth.currentUser()).uid;
  }

  static Future<void> resetPassword(String email) async {
    await _auth.sendPasswordResetEmail(email: email);
  }

  static Future<FirebaseUser> signUp(String email, String password) async {
    final FirebaseUser user = (await _auth.createUserWithEmailAndPassword(
        email: email, password: password)).user;

    if (!user.isEmailVerified) {
      user.sendEmailVerification();
    }

    return user;
  }

  static Future<FirebaseUser> signIn(String email, String password) async {
    final FirebaseUser user = (await _auth.signInWithEmailAndPassword(
        email: email, password: password)).user;

    if (!user.isEmailVerified) {
      user.sendEmailVerification();
    }

    return user;
  }

  static Future<void> signOut() async {
    await FirebaseAuth.instance.signOut();
  }

  static Stream<FirebaseUser> onAuthChanged() {
    return FirebaseAuth.instance.onAuthStateChanged;
  }

  static Future<void> deleteUser(String password) async {
    final FirebaseUser user = await FirebaseAuth.instance.currentUser();

    await user.reauthenticateWithCredential(EmailAuthProvider.getCredential(email: user.email, password: password));

    await user.delete();
  }

}